import 'dart:io';

import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:hv_sdk_wrapper_plugin/hv_sdk_wrapper_plugin.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _didInit = 'Not yet', _docsCapture = '?';
  String imagePath;

  @override
  void initState() {
    super.initState();
    imagePath = null;
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
        home: Scaffold(
      appBar: AppBar(
        title: const Text('Plugin example app'),
      ),
      body: SingleChildScrollView(
        child: Center(
            child: Column(children: <Widget>[
          Container(
            margin: EdgeInsets.all(25),
            child: MaterialButton(
              child: Text(
                "Initialize",
                style: TextStyle(fontSize: 20.0),
              ),
              color: Colors.blueAccent,
              textColor: Colors.white,
              onPressed: () async {
                await HvSdkWrapperPlugin.initialize(
                    "857acb",
                    "e0d888e703691bccbf92",
                    (await HvSdkWrapperPlugin.getValidParams())["RegionIndia"]);
              },
            ),
          ),
          Container(
            margin: EdgeInsets.all(25),
            child: MaterialButton(
              child: Text(
                "Open Docs Capture",
                style: TextStyle(fontSize: 20.0),
              ),
              color: Colors.blueAccent,
              textColor: Colors.white,
              onPressed: () async {
                Map docCaptureMap = await HvSdkWrapperPlugin.docsCaptureStart();
                // _showToast(context, docCaptureMap);
                //   debugPrint(docCaptureMap.toString());
                Map docResultObj = docCaptureMap["resultObj"];
                Map docErrorObj = docCaptureMap["errorObj"];
                for (var k in docResultObj.keys) {
                  debugPrint("Key : $k, value : ${docResultObj[k]}");
                }
                var docImageUri = docResultObj["imageUri"];
                var docParams = new Map();
                var docHeaders = new Map();
                Map ocrMap = await HvSdkWrapperPlugin.networkHelperMakeOCRCall(
                    "https://ind-docs.hyperverge.co/v2.0/readKYC",
                    docImageUri,
                    docParams,
                    docHeaders);
                debugPrint("OCRCall");
                for (var k in ocrMap.keys) {
                  debugPrint("Key : $k, value : ${ocrMap[k]}");
                }

                Map faceCaptureMap =
                    await HvSdkWrapperPlugin.faceCaptureStart();
                // _showToast(context, faceCaptureMap);
                //   debugPrint(faceCaptureMap.toString());
                Map faceResultObj = faceCaptureMap["resultObj"];
                Map faceErrorObj = faceCaptureMap["errorObj"];
                for (var k in faceResultObj.keys) {
                  debugPrint("Key : $k, value : ${faceResultObj[k]}");
                }

                debugPrint(
                    "Here's the image Uri: ${faceResultObj["imageUri"]}");
                setState(() {
                  imagePath = faceResultObj["imageUri"];
                });

                var faceImageUri = faceResultObj["imageUri"];
                var faceParams = new Map();
                var faceHeaders = new Map();
                Map faceMatchMap =
                    await HvSdkWrapperPlugin.networkHelperMakeFaceMatchCall(
                        "https://apac.faceid.hyperverge.co/v1/photo/verifyPair",
                        faceImageUri,
                        docImageUri,
                        faceParams,
                        faceHeaders);
                debugPrint("FaceMATCH");
                for (var k in faceMatchMap.keys) {
                  debugPrint("Key : $k, value : ${faceMatchMap[k]}");
                }
              },
            ),
          ),
          Container(
            margin: EdgeInsets.all(25),
            child: MaterialButton(
              child: Text(
                "Open face Capture",
                style: TextStyle(fontSize: 20.0),
              ),
              color: Colors.blueAccent,
              textColor: Colors.white,
              onPressed: () async {
                Map map = await HvSdkWrapperPlugin.faceCaptureStart();
                // _showToast(context, map);
                for (var k in map.keys) {
                  debugPrint("Key : $k, value : ${map[k]}");
                }
              },
            ),
          ),
          Container(
            margin: EdgeInsets.all(25),
            child: MaterialButton(
              child: Text(
                "Open QR Scan Capture",
                style: TextStyle(fontSize: 20.0),
              ),
              color: Colors.blueAccent,
              textColor: Colors.white,
              onPressed: () async {
                Map map = await HvSdkWrapperPlugin.qrScanCaptureStart();
                // _showToast(context, map);
                // debugPrint(map.toString());
                for (var k in map.keys) {
                  debugPrint("Key : $k, value : ${map[k]}");
                }
              },
            ),
          ),
          Row(
            children: [
              Expanded(
                child: Container(
                  padding: EdgeInsets.all(30),
                  margin: EdgeInsets.only(top: 50),
                  child: Image(
                    fit: BoxFit.fitWidth,
                    image: imagePath == null
                        ? AssetImage('images/flutter-logo.png')
                        : FileImage(
                            File(imagePath),
                          ),
                  ),
                ),
              ),
            ],
          ),
        ])),
      ),
    ));
  }
  /*void _showToast(BuildContext context,Map map) {
    final scaffold = Scaffold.of(context);
    scaffold.showSnackBar(
      SnackBar(
        content: Text(map.toString()),
      ),
    );
  }*/
}
